package com.hchyun.test.dao;

import java.util.List;

import com.hchyun.test.entity.TestTree;

/**
 * 树测试Mapper接口
 *
 * @author hchyun
 * @date 2021-01-23
 */
public interface TestTreeDao {
    /**
     * 查询树测试
     *
     * @param id 树测试ID
     * @return 树测试
     */
    TestTree selectTestTreeById(Long id);

    /**
     * 查询树测试列表
     *
     * @param testTree 树测试
     * @return 树测试集合
     */
    List<TestTree> selectTestTreeList(TestTree testTree);

    /**
     * 新增树测试
     *
     * @param testTree 树测试
     * @return 结果
     */
    int insertTestTree(TestTree testTree);

    /**
     * 修改树测试
     *
     * @param testTree 树测试
     * @return 结果
     */
    int updateTestTree(TestTree testTree);

    /**
     * 删除树测试
     *
     * @param id 树测试ID
     * @return 结果
     */
    int deleteTestTreeById(Long id);

    /**
     * 批量删除树测试
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTestTreeByIds(Long[] ids);
}
